@@ -2,7 +2,7 @@ fdt_cat.default <- function (x,
                              sort=TRUE,
                              decreasing=TRUE, ...)
 {
-  x <- na.omit(x)
+  #x <- na.omit(x)
 
   res <- make.fdt_cat.simple(x,
                              sort,
